==> galeon-0.11.3.tar.gz: galeon-0.11.3/src/mozilla.h <==
/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "print.h"

#ifndef __mozilla_h
#define __mozilla_h

typedef struct
{
	gchar *img; 
	gchar *link; 
	gchar *linktext;
	gboolean framed_page;
	gint context;
} WrapperContextInfo;

typedef struct
{
	WrapperContextInfo ctx;
	gulong key;
	gint modifier;
} WrapperKeyEventInfo;

typedef struct
{
	WrapperContextInfo ctx;
	gint button;
	gint modifier;
	guint timestamp;
} WrapperMouseEventInfo;

typedef struct
{
	gchar *search_string;
	gboolean backwards;
	gboolean wrap;
	gboolean entire_word;
	gboolean match_case;
} WrapperSearchProperties;

#define COOKIEPERMISSION 0
#define IMAGEPERMISSION 1
#define PASSWORDMANAGER_ID "@mozilla.org/passwordmanager;1"
#define UTF8_ENCODER_ID "@mozilla.org/intl/unicode/encoder;1?charset=UTF-8"  
#define UTF8_DECODER_ID "@mozilla.org/intl/unicode/decoder;1?charset=UTF-8"

#define ACTION_NONE 0
#define ACTION_VIEWSOURCE 1
#define ACTION_SETBACKGROUND 2 

#ifdef __cplusplus
extern "C"
{
#endif

/* Preferences */
gboolean mozilla_load_prefs (void);
gboolean mozilla_save_prefs (void);
gboolean mozilla_preference_set (const char *preference_name,
				 const char *new_value);
gboolean mozilla_preference_set_boolean (const char *preference_name,
					 gboolean  new_boolean_value);
gboolean mozilla_preference_set_int (const char *preference_name,
				     int new_int_value);

/* Wrapper initialization */
gpointer mozilla_wrapper_init (GaleonEmbed *embed,
			       gboolean attach_listener);
gboolean mozilla_wrapper_destroy (GaleonEmbed *embed);

/* Base functionalities */
gboolean mozilla_find (GaleonEmbed *embed,
		       WrapperSearchProperties *properties);
gboolean mozilla_save_url (GaleonEmbed *embed, const char *url, 
			   char *file_name, int action);
gboolean mozilla_save_link (GaleonEmbed *embed, const char *url);
void mozilla_delete_temp_file_on_exit (const char *filename);
gboolean mozilla_reload (GaleonEmbed *embed);
gboolean mozilla_print (GaleonEmbed *embed, PrintInfo *info);
gboolean mozilla_set_zoom (GaleonEmbed *embed, float f);
gboolean mozilla_get_zoom (GaleonEmbed *embed, float *f);
char *mozilla_session_history_get_url (GaleonEmbed *embed, int index);
char *mozilla_session_history_get_url_relative (GaleonEmbed *embed,
						int offset);
gboolean mozilla_session_history_get_all_titles (GaleonEmbed *embed,
						 char **titles[],
						 int *count, int *index);
gboolean mozilla_session_history_go (GaleonEmbed *embed, int index);
gchar *mozilla_get_main_document_url (GaleonEmbed *embed);
gchar *mozilla_get_document_url (GaleonEmbed *embed);
gchar *mozilla_get_document_title (GaleonEmbed *embed, gchar **title_utf8);
void mozilla_clear_cache (unsigned long cache);
gboolean mozilla_set_offline (GaleonEmbed *embed, gboolean offline);
void mozilla_activate (GaleonEmbed *embed);
void mozilla_deactivate (GaleonEmbed *embed);

/* Clipboard */
gboolean mozilla_can_cut_selection (GaleonEmbed *embed);
gboolean mozilla_can_copy_selection (GaleonEmbed *embed);
gboolean mozilla_can_paste (GaleonEmbed *embed);
void mozilla_cut_selection (GaleonEmbed *embed);
void mozilla_copy_selection (GaleonEmbed *embed);
void mozilla_paste (GaleonEmbed *embed);

/* Utils */
gboolean mozilla_get_key_event_info (GaleonEmbed *embed,
				     gpointer event,
				     WrapperKeyEventInfo *info);
gboolean mozilla_get_mouse_event_info (GaleonEmbed *embed,
				       gpointer event,
				       WrapperMouseEventInfo *info);
void mozilla_free_context_info_sub (WrapperContextInfo *ctx);

/* Charsets and fonts*/
void mozilla_get_charsets (GHashTable **charsets,
			   GList **sorted_charset_titles);
void mozilla_force_character_set (GaleonEmbed *embed,
				  char *force_character_set);
char* mozilla_get_default_font (const char *language, 
				const char *type,
				const char *default_font);
/* Cookies manager */
void mozilla_block_url (const char *imgURL);
GList *mozilla_list_cookies (void);
void mozilla_set_permission (GaleonEmbed *embed, gboolean permit, 
				    int type);
GList *mozilla_get_permissions (int type);
gboolean mozilla_remove_cookies (GList *gone);
gboolean mozilla_remove_permissions (GList *gone, int type);

/* Password Manager */
GList *mozilla_list_passwords (PasswordType type);
gboolean mozilla_remove_passwords (GList *gone, PasswordType type);

/* Others */
gboolean mozilla_copy_session_history (GaleonEmbed *embed,
				       GaleonEmbed *dest);
gboolean mozilla_get_favicon_location (GaleonEmbed *embed, gchar **url);

#ifdef __cplusplus
}
#endif 

#ifdef __cplusplus

#include <nscore.h>
#include "nsIDOMWindow.h"

extern "C"
{
gchar *mozilla_unicode_to_utf8 (const PRUnichar *uniStr);
gchar *mozilla_unicode_to_locale (const PRUnichar *uniStr);
PRUnichar *mozilla_utf8_to_unicode (const gchar *utfStr);
PRUnichar *mozilla_locale_to_unicode (const gchar *locStr);
GtkWidget *mozilla_find_gtk_parent (nsIDOMWindow *domWindow);
}

#endif

#endif /* __mozilla_h */

==> galeon-0.12.tar.gz: galeon-0.12/src/mozilla.h <==
/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "print.h"

#ifndef __mozilla_h
#define __mozilla_h

typedef struct
{
	gchar *img; 
	gchar *link; 
	gchar *linktext;
	gboolean framed_page;
	gint context;
} WrapperContextInfo;

typedef struct
{
	WrapperContextInfo ctx;
	gulong key;
	gint modifier;
} WrapperKeyEventInfo;

typedef struct
{
	WrapperContextInfo ctx;
	gint button;
	gint modifier;
	guint timestamp;
} WrapperMouseEventInfo;

typedef struct
{
	gchar *search_string;
	gboolean backwards;
	gboolean wrap;
	gboolean entire_word;
	gboolean match_case;
} WrapperSearchProperties;

#define COOKIEPERMISSION 0
#define IMAGEPERMISSION 1
#define PASSWORDMANAGER_ID "@mozilla.org/passwordmanager;1"
#define UTF8_ENCODER_ID "@mozilla.org/intl/unicode/encoder;1?charset=UTF-8"  
#define UTF8_DECODER_ID "@mozilla.org/intl/unicode/decoder;1?charset=UTF-8"

#define ACTION_NONE 0
#define ACTION_VIEWSOURCE 1
#define ACTION_SETBACKGROUND 2 

#ifdef __cplusplus
extern "C"
{
#endif

/* Preferences */
gboolean mozilla_load_prefs (void);
gboolean mozilla_save_prefs (void);
gboolean mozilla_preference_set (const char *preference_name,
				 const char *new_value);
gboolean mozilla_preference_set_boolean (const char *preference_name,
					 gboolean  new_boolean_value);
gboolean mozilla_preference_set_int (const char *preference_name,
				     int new_int_value);
gchar *mozilla_preference_get(const char *preference_name);
gint mozilla_preference_get_int (const char *preference_name);

/* Wrapper initialization */
gpointer mozilla_wrapper_init (GaleonEmbed *embed);
gboolean mozilla_wrapper_destroy (GaleonEmbed *embed);

/* Base functionalities */
gboolean mozilla_find (GaleonEmbed *embed,
		       WrapperSearchProperties *properties);
gboolean mozilla_save_url (GaleonEmbed *embed, const char *url, 
			   char *file_name, int action);
gboolean mozilla_save_link (GaleonEmbed *embed, const char *url);
gboolean mozilla_save_document (GaleonEmbed *embed, char *filename,
				const char *datapath, int action,
				gboolean mainDoc);
void mozilla_delete_temp_file_on_exit (const char *filename);
gboolean mozilla_reload (GaleonEmbed *embed);
	gboolean mozilla_print (GaleonEmbed *embed, PrintInfo *info,
			gboolean preview);
gboolean mozilla_set_zoom (GaleonEmbed *embed, float f);
gboolean mozilla_get_zoom (GaleonEmbed *embed, float *f);
char *mozilla_session_history_get_url (GaleonEmbed *embed, int index);
char *mozilla_session_history_get_url_relative (GaleonEmbed *embed,
						int offset);
gboolean mozilla_session_history_get_all_titles (GaleonEmbed *embed,
						 char **titles[],
						 int *count, int *index);
gboolean mozilla_session_history_go (GaleonEmbed *embed, int index);
gchar *mozilla_get_main_document_url (GaleonEmbed *embed);
gchar *mozilla_get_document_url (GaleonEmbed *embed);
gchar *mozilla_get_document_title (GaleonEmbed *embed, gchar **title_utf8);
void mozilla_clear_cache (unsigned long cache);
gboolean mozilla_set_offline (GaleonEmbed *embed, gboolean offline);
void mozilla_activate (GaleonEmbed *embed);
void mozilla_deactivate (GaleonEmbed *embed);

/* Clipboard */
gboolean mozilla_can_cut_selection (GaleonEmbed *embed);
gboolean mozilla_can_copy_selection (GaleonEmbed *embed);
gboolean mozilla_can_paste (GaleonEmbed *embed);
void mozilla_cut_selection (GaleonEmbed *embed);
void mozilla_copy_selection (GaleonEmbed *embed);
void mozilla_paste (GaleonEmbed *embed);

/* Utils */
gboolean mozilla_get_key_event_info (GaleonEmbed *embed,
				     gpointer event,
				     WrapperKeyEventInfo *info);
gboolean mozilla_get_mouse_event_info (GaleonEmbed *embed,
				       gpointer event,
				       WrapperMouseEventInfo *info);
void mozilla_free_context_info_sub (WrapperContextInfo *ctx);

/* Charsets and fonts*/
void mozilla_get_charsets (GHashTable **charsets,
			   GList **sorted_charset_titles);
void mozilla_force_character_set (GaleonEmbed *embed,
				  char *force_character_set);

/* Cookies manager */
void mozilla_block_url (const char *imgURL);
GList *mozilla_list_cookies (void);
void mozilla_set_permission (GaleonEmbed *embed, gboolean permit, 
				    int type);
GList *mozilla_get_permissions (int type);
gboolean mozilla_remove_cookies (GList *gone);
gboolean mozilla_remove_permissions (GList *gone, int type);

/* Password Manager */
GList *mozilla_list_passwords (PasswordType type);
gboolean mozilla_remove_passwords (GList *gone, PasswordType type);

/* Others */
gboolean mozilla_copy_session_history (GaleonEmbed *embed,
				       GaleonEmbed *dest);
gboolean mozilla_get_favicon_location (GaleonEmbed *embed, gchar **url);
gboolean mozilla_show_java_console (void);
gboolean mozilla_show_javascript_console (void);

#ifdef __cplusplus
}
#endif 

#ifdef __cplusplus

#include <nscore.h>
#include "nsIDOMWindow.h"

extern "C"
{
gchar *mozilla_unicode_to_utf8 (const PRUnichar *uniStr);
gchar *mozilla_unicode_to_locale (const PRUnichar *uniStr);
PRUnichar *mozilla_utf8_to_unicode (const gchar *utfStr);
PRUnichar *mozilla_locale_to_unicode (const gchar *locStr);
GtkWidget *mozilla_find_gtk_parent (nsIDOMWindow *domWindow);
}

#endif

#endif /* __mozilla_h */
